import java.util.*;
import java.awt.*;

/** Klasse zur Speicherung eines Kurvenelements
  * eines Zeichens.
  *
  * @author Bernhard Fiser 0109815
  */
public class CharCurveElement extends CharElement
{
	private int	coord[];

	/** Initialisierung des Kurvenelements */
	public CharCurveElement()
	{
		int	i;

		/* Koordinatenfeld initialisieren und auf 0 setzen */
		coord = new int[5];
		for (i = 0; i < 5; i++)
			coord[i] = 0;
	}

	/** Daten aus dem String s in das Koordinationfeld bernehmen */
	public boolean parseLine(String s)
	{
		StringTokenizer	st;
		int		i;
		String		t;

		/* StringTokenizer inititalisieren,
		 * Trennzeichen ' ' */
		i = 0;
		st = new StringTokenizer(s, " ");
		while (st.hasMoreTokens())
		{
			t = st.nextToken();
			switch (i)
			{
				/* Das erste Element bestimmt den Typ.
				 * Falls nicht vom Type 'kurve', dann Fehler
				 * zurckgeben */
				case 0 :
					if (t.compareToIgnoreCase("kurve") != 0)
						return(false);
					break;

				/* Die nchsten 5 Elemente bestimmen die Koordinaten
				 * x, y, Radius, Anfangswinkel und Bogenwinkel. */
				case 1 :
				case 2 :
				case 3 :
				case 4 :
				case 5 :
					/* In Integer umkonvertieren, und Fehler zurckgeben
					 * falls Konvertierung nicht mglich */
					try { this.coord[i - 1] = Integer.parseInt(t); }
					catch (NumberFormatException e) { return(false); }
					/* Bei einer negativen Koordinate ebenfalls einen
					 * Fehler zurckgeben */
					if (this.coord[i - 1] < 0)
						return(false);
					break;

				/* Sollten mehr als diese 6 Elemente existieren,
				 * dann Fehler zurckgeben */
				default :
					return(false);
			}
			/* Element- (Token-) zhler erhhen */
			i++;
		}
		/* Sollten weniger als 6 Elemente (Tokens) im String enthalten sein,
		 * dann Fehler zurckgeben */
		if (i < 6)
			return(false);
		/* Andernfalls alles OK */
		return(true);
	}

	/** Dieses Element graphisch darstellen */
	public void draw(int x, int y, int zoom, Graphics g)
	{
		int	xs, ys, w;

		/* Startkoordinaten des Rechtecks in dem sich der Bogen befindet
		 * berechnen. Siehe Angabe und JDK Dokumentation 'fillArc' */
		xs = (this.coord[0] - this.coord[2]) * zoom + x;
		ys = (this.coord[1] - this.coord[2]) * zoom + y;
		w = this.coord[2] * 2 * zoom;

		/* Bogen zeichnen */
		g.setColor(Color.black);
		g.fillArc(xs, ys, w, w, this.coord[3], this.coord[4]);

		/* Rechteck korrigieren, innen darf es nicht gefllt sein, d.h.
		 * dieser Bereich wird nochmals wei bermalt */
		xs += zoom;
		ys += zoom;
		w -= zoom * 2;
		
		/* inneren Bogen zeichen */
		g.setColor(Color.white);
		g.fillArc(xs, ys, w, w, this.coord[3], this.coord[4]);
	}

}
